package com.ruoyi.project.training.service;

import java.util.List;
import com.ruoyi.project.training.domain.TWorklicenseCertificate;

/**
 * 上岗证/作业证书一览Service接口
 * 
 * @author ssy
 * @date 2024-03-04
 */
public interface ITWorklicenseCertificateService 
{
    /**
     * 查询上岗证/作业证书一览
     * 
     * @param id 上岗证/作业证书一览ID
     * @return 上岗证/作业证书一览
     */
    public TWorklicenseCertificate selectTWorklicenseCertificateById(Long id);

    /**
     * 查询上岗证/作业证书一览列表
     * 
     * @param tWorklicenseCertificate 上岗证/作业证书一览
     * @return 上岗证/作业证书一览集合
     */
    public List<TWorklicenseCertificate> selectTWorklicenseCertificateList(TWorklicenseCertificate tWorklicenseCertificate);

    /**
     * 新增上岗证/作业证书一览
     * 
     * @param tWorklicenseCertificate 上岗证/作业证书一览
     * @return 结果
     */
    public int insertTWorklicenseCertificate(TWorklicenseCertificate tWorklicenseCertificate);

    /**
     * 修改上岗证/作业证书一览
     * 
     * @param tWorklicenseCertificate 上岗证/作业证书一览
     * @return 结果
     */
    public int updateTWorklicenseCertificate(TWorklicenseCertificate tWorklicenseCertificate);

    /**
     * 批量删除上岗证/作业证书一览
     * 
     * @param ids 需要删除的上岗证/作业证书一览ID
     * @return 结果
     */
    public int deleteTWorklicenseCertificateByIds(Long[] ids);

    /**
     * 删除上岗证/作业证书一览信息
     * 
     * @param id 上岗证/作业证书一览ID
     * @return 结果
     */
    public int deleteTWorklicenseCertificateById(Long id);
}
